==> haskell-svg-builder-0.1.1-252-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-ISgmOhRDSsKEVG5cWWdWEr
key:                  svg-builder-0.1.1-ISgmOhRDSsKEVG5cWWdWEr
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  ab4431b4883295892f5c66926b7ab9b3
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-ISgmOhRDSsKEVG5cWWdWEr
depends:
    base-4.17.2.1 blaze-builder-0.4.4-J87LvVgADYa5gww986bADm
    bytestring-0.11.5.3 hashable-1.4.4.0-5SoCNaysfySGuPwu0aljBu
    text-2.0.2 unordered-containers-0.2.20-AeV3HTkHtCc6BQ9fzLSSB8

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-svg-builder-0.1.1-253-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-16YQNyZVTpA1SLW3r3ktQ
key:                  svg-builder-0.1.1-16YQNyZVTpA1SLW3r3ktQ
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  95fe84210f0393457a9b68a1c1d61958
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-16YQNyZVTpA1SLW3r3ktQ
depends:
    base-4.17.2.1 blaze-builder-0.4.4-EYzzAuOKf5mlUrLaPwbAW
    bytestring-0.11.5.3 hashable-1.4.4.0-2lvxXC6j7O5I2GR31C0SqX
    text-2.0.2 unordered-containers-0.2.20-G9Xtyt8hv5K8HhfrH8JX1r

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
